library(XML)   # En Ubuntu cal instal.lar el paquet libxml2-dev
library(RCurl) # for getURL()

url <- "https://www.fisterra.com/formacion/metodologia-investigacion/tecnicas-regresion-regresion-lineal-simple/"
html <- getURL(url)
tbls_xml <- readHTMLTable(html, stringsAsFactors = FALSE)

typeof(tbls_xml)

length(tbls_xml)

head(tbls_xml[[2]])

dades <- readHTMLTable(html, which=2, header=F, skip.rows = 1,
                       colClasses = rep("integer", 6))
head(dades)
colnames(dades) <- c("num","tas","edat","num","tas","edat")
dades <- rbind(dades[,1:3],dades[,4:6])
dades <- dades[-70,]
str(dades)

attach(dades)
lmod <- lm(tas ~ edat, data=dades) 
plot(edat,tas)
abline(lmod)

# Tabla 2
summary(lmod)
coef(lmod)
anova(lmod)

# Gràfic amb les linees dels IC per a les prediccions
library(UsingR)
simple.lm(edat,tas, show.ci=TRUE)

# El mateix gràfic amb colors
edat_grid <- seq(min(edat), max(edat), by = 1)
dist_ci_band <- predict(lmod, 
                       newdata = data.frame(edat = edat_grid), 
                       interval = "confidence", level = 0.95)
dist_pi_band <- predict(lmod, 
                       newdata = data.frame(edat = edat_grid), 
                       interval = "prediction", level = 0.95) 

plot(tas ~ edat, data = dades,
     pch  = 20,
     cex  = 2,
     col  = "grey",
     ylim = c(min(dist_pi_band), max(dist_pi_band)))
abline(lmod, lwd = 5, col = "darkorange")
lines(edat_grid, dist_ci_band[,"lwr"], col = "dodgerblue", lwd = 3, lty = 2)
lines(edat_grid, dist_ci_band[,"upr"], col = "dodgerblue", lwd = 3, lty = 2)
lines(edat_grid, dist_pi_band[,"lwr"], col = "dodgerblue", lwd = 3, lty = 3)
lines(edat_grid, dist_pi_band[,"upr"], col = "dodgerblue", lwd = 3, lty = 3)
points(mean(edat), mean(tas), pch = "+", cex = 3)

# També es pot fer amb el paquet ggplot2
library(ggplot2)
pred.int <- predict(lmod, interval="prediction")
dades.pred <- cbind(dades,pred.int)
p <- ggplot(dades.pred, aes(edat,tas)) +
            geom_point() + stat_smooth(method = lm)
# ara afegim els intervals de predicció
p + geom_line(aes(y=lwr), color="red", linetype="dashed") +
    geom_line(aes(y=upr), color="red", linetype="dashed")
