########################
# Matching and ordering
########################
#
## match(<vec1>, <vec2>)
## returns a vector of the same length than <vec1>
## for each element of <vec1>, returns the
## position of the first occurrence in <vec2> (NA otherwise)

x <- c(1,1,3:1,1:4,3)
# 1 1 3 2 1 1 2 3 4 3
match(3:4,x)

## <vector> %in% <table>
## returns a logical vector
v <- rep(1:5,rep(3,5))
v
two4 <- x %in% c(2,4)
two4
# We can use this to pick out the 2s and the 4s
v[two4]

## order(<vector>)
## Returns the vector of subscripts giving
## the order in which elements must be taken

y <- c(9,9:1)
# 9 9 8 7 6 5 4 3 2 1
z <- c(2,1:9)
(ii <- order(x, y , z))
## 6  5  2  1  7  4 10  8  3  9
rbind(x,y,z)[,ii] # shows the reordering (ties via 2nd & 3rd arg)

## sort(<vector>)
## sort a vector into ascending (or descending) order
sort(x, decreasing=T)

## rev(<vector>)
## reverses the elements of x
rev(sort(x))

## rank(<vector>)
## Returns the ranks of the successive elements
rank(x)

## Data selection and manipulation

## which.max(<vector>)
## returns the index of the greatest element of <vector>
which.max(x)

## which.min(<vector>)
## returns the index of the smallest element of <vector>
which.min(x)

## which(<vector> == a)
## returns a vector of the indices of <vector> if the comparison is true
which(x == 3)

## na.omit(x)
## suppresses the observations with missing data (NA)
## suppresses the corresponding line if x is a matrix or a data frame

## na.fail(x)
## returns an error message if x contains at least one NA

## unique(x)
## if x is a vector or a data frame, returns a similar object but with
## the duplicate elements suppressed
sort(unique(x))

## table(x)
table(x)

## subset(x,...)
